@@ -41,8 +41,6 @@
 
 #define KIDLETIME_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KIDLETIME_NO_DEPRECATED) && !defined(KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KIDLETIME_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIDLETIME_NO_DEPRECATED
-#  define KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KIDLETIME_NO_DEPRECATED_WARNINGS
 #  define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIDLETIME_DEPRECATED_WARNINGS_SINCE KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KIDLETIME_DEPRECATED
-#  define KIDLETIME_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KIDLETIME_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KIDLETIME_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
